import React, { useState } from "react"
import { Box, Heading, VStack } from "@chakra-ui/react"
import { ContentContainer } from "components/utils/ContentContainer"
import { GetVulnerabilityAggParams, VulnerabilitySummary } from "@common/types"
import SensitiveDataFilters from "./Filters"
import List from "./List"
import { getVulnerabilitySummary } from "api/alerts/vulnerabilities"
import AggVulnerabilityChart from "./AggVulnerabilityChart"

interface VulnerabilityPageProps {
  initSummary: VulnerabilitySummary
  hosts: string[]
}

const VulnerabilityPage: React.FC<VulnerabilityPageProps> = React.memo(
  ({ initSummary, hosts }) => {
    const [fetching, setFetching] = useState<boolean>(false)
    const [summary, setSummary] = useState<VulnerabilitySummary>(initSummary)
    const [params, setParamsInner] = useState<GetVulnerabilityAggParams>({
      hosts: [],
      riskScores: [],
    })

    const setParams = (
      t: (params: GetVulnerabilityAggParams) => GetVulnerabilityAggParams,
    ) => {
      setFetching(true)
      const newParams = t(params)
      setParamsInner(newParams)
      getVulnerabilitySummary(newParams)
        .then(e => setSummary(e))
        .catch(e => console.error(e))
        .finally(() => setFetching(false))
    }

    return (
      <ContentContainer maxContentW="100rem" px="8" py="8">
        <VStack w="full" alignItems="flex-start">
          <Heading fontWeight="medium" size="lg" mb="4">
            Vulnerabilities
          </Heading>
        </VStack>
        <VStack
          w="full"
          alignItems="flex-start"
          borderWidth="1px"
          rounded="md"
          spacing="0"
          overflow="hidden"
        >
          <Box p="4" borderBottom="1px" borderColor="inherit" w="full">
            <SensitiveDataFilters
              hostList={hosts}
              hosts={params.hosts}
              riskScores={params.riskScores}
              setParams={setParams}
            />
          </Box>
          <AggVulnerabilityChart
            vulnerabilityTypeCount={summary.vulnerabilityTypeCount}
            totalVulnerabilities={summary.totalVulnerabilities}
            totalEndpoints={summary.totalEndpoints}
          />
          <Box w="full" borderTop="1px" borderColor="inherit">
            <List items={summary.vulnerabilityItems} params={params} />
          </Box>
        </VStack>
      </ContentContainer>
    )
  },
)

export default VulnerabilityPage
